/**
 A processing sketch to visualize calendar events as flowers.
 Every event in your ical file is a flower, the size depends 
 on the duration of the event.<br> 
 by <a href="http://www.local-guru.net/blog">Guru</a>
 */
 
import guru.ical4p.*;

long xmin = Long.MAX_VALUE, xmax = 0;
long hmin = Long.MAX_VALUE, hmax = 0;

PFont font;
Weather weather = new Weather( "http://localhost:2000/weather" );
color[] colors = new color[] {
   color( 255,0,0 ),
   color( 255, 100, 0 ),
   color( 128, 0, 255 )
};

Set events;

void setup() {
  size(600,300);
  smooth();
  font = loadFont("BitstreamVeraSans-Roman-48.vlw");
  noLoop();
  start( 30 * 60 * 1000);
  
}

void draw() {  
  getEvents();
  background( getSkyColor());  
  colorMode(RGB,255,255,255);
  
  fill( color( 128, 255, 128 ));
  noStroke();
  rect(0, 200, width, 100);
  weather.draw();
  indoorTemp();
  for( Iterator i = events.iterator(); i.hasNext(); ) {
    ICalEvent e = (ICalEvent)i.next();
   
    Flower f = new Flower( map( e.getStart().getTime(), xmin, xmax, 50, 550),
           map(e.getDurInMin(), hmin, hmax, 20, 70),
           random(5,8),
           colors[ (int)random(3)]);
    f.draw();     
  }
}



color getSkyColor() {
  float b = (1 - cos(radians(float(hour())*15 ))) * 50;
  colorMode(HSB, 360, 100, 100);
  color c = color( 210, 61, b);

  return c;
}

void getEvents() {
  ICal cal = new ICal();
 // cal.parse( createInput("test.ics"));
  cal.parse( createInput("http://localhost:2000/ical" ));
  events = cal.getEvents();
  
  for (Iterator i = events.iterator(); i.hasNext(); ) {
    ICalEvent e = (ICalEvent)i.next();
    if (e.getStart().getTime() < xmin) { xmin = e.getStart().getTime(); }
    if (e.getStart().getTime() > xmax) { xmax = e.getStart().getTime(); }
 
    if (e.getDurInMin() < hmin) { hmin = e.getDurInMin(); }
    if (e.getDurInMin() > hmax) { hmax = e.getDurInMin(); }
  }
}

void start( final int mil ) { 
   new Thread() { 
   public void run() {
     while( true ) {     
        delay( mil );
        redraw(); 
      }
   }
 }.start();
}

void indoorTemp() {
  String[] data = loadStrings("http://localhost:2000/indoor" );
  String temp = data[0];
  
  fill( 0, 64 );
  noStroke();
  beginShape();
  vertex( width - 110, 290 );
  vertex( width - 110, 230 );
  vertex( width - 60, 210 );
  vertex( width - 10, 230 );
  vertex( width - 10, 290 );    
  endShape();
  
  //rect( width - 110, 210, 100, 80 );
  fill( color( 128, 255, 128 ));
  textAlign(CENTER);
  textFont( font, 32 );
  text( temp, width - 60, 270 );

  
}


